@@ -209,7 +209,7 @@ def geodesic_distances(X, kmax):
 		dist = sp.csgraph.floyd_warshall(knn, directed=False)
 
 
-	return dist/dist.max(), kmin, not_connected, connected_element, index
+	return dist, kmin, not_connected, connected_element, index
 
 def euclidean_distances(data):
 	row, col = np.shape(data)
